@@ -14,18 +14,18 @@ import anyconfig.utils as U
 # pylint: disable=W0611
 # Import some global constants will be re-exported:
 from anyconfig.mergeabledict import MS_REPLACE, MS_NO_REPLACE, \
-    MS_DICTS, MS_DICTS_AND_LISTS, MERGE_STRATEGIES
+    MS_DICTS, MS_DICTS_AND_LISTS, MERGE_STRATEGIES, get  # flake8: noqa
 # pylint: enable=W0611
 
 # pylint: disable=C0103
 # Re-export:
-list_types = Backends.list_types
-getLogger = G.get_logger
+list_types = Backends.list_types  # flake8: noqa
+getLogger = G.get_logger  # flake8: noqa
 
 # aliases:
 container = M.MergeableDict
 logging = G.LOGGER
-# pylint: enable=W0611
+# pylint: enable=C0103
 
 
 def set_loglevel(level):
@@ -72,6 +72,8 @@ def single_load(config_path, forced_type=None, **kwargs):
         anyconfig.mergeabledict.MergeableDict by default) supports merge
         operations.
     """
+    config_path = U.ensure_expandusr(config_path)
+
     cparser = find_loader(config_path, forced_type)
     if cparser is None:
         return None
