@@ -5,6 +5,7 @@
 import anyconfig.api as A
 import anyconfig.compat as C
 import anyconfig.globals as G
+import anyconfig.getset as GS
 
 import codecs
 import locale
@@ -43,7 +44,8 @@ Examples:
   %prog '/etc/xyz/conf.d/*.json' -o xyz.yml \\
     -A obsoletes:sysdata;conflicts:sysdata-old
   %prog /etc/foo.json /etc/foo/conf.d/x.json /etc/foo/conf.d/y.json
-  %prog '/etc/foo.d/*.json' -M noreplace"""
+  %prog '/etc/foo.d/*.json' -M noreplace
+  %prog '/etc/foo.d/*.json' --get a.b.c"""
 
 
 def to_log_level(level):
@@ -81,6 +83,10 @@ If this option is not set, original parser is used: 'K:V' will become {K: V},
 become {K_0: V_0, K_1: V_1} (where the tyep of K is str, type of V is one of
 Int, str, etc.""" % ctypes_s
 
+    get_help = ("Specify key path to get part of config, for example, if a "
+                "config {'a': {'b': {'c': 0, 'd': 1}}} '--get a.b.c' gives "
+                "0 and '--get a.b' gives {'c': 0, 'd': 1}.")
+
     parser = optparse.OptionParser(usage, version="%%prog %s" % G.VERSION)
     parser.set_defaults(**defaults)
 
@@ -96,6 +102,8 @@ Int, str, etc.""" % ctypes_s
     parser.add_option("-A", "--args", help="Argument configs to override")
     parser.add_option("", "--atype", choices=ctypes, help=af_help)
 
+    parser.add_option("", "--get", help=get_help)
+
     parser.add_option("-s", "--silent", action="store_const", dest="loglevel",
                       const=0, help="Silent or quiet mode")
     parser.add_option("-q", "--quiet", action="store_const", dest="loglevel",
@@ -131,6 +139,9 @@ def main(argv=sys.argv):
         diff = A.loads(options.args, options.atype)
         data.update(diff, options.merge)
 
+    if options.get:
+        data = GS.get(data, options.get, sep='.')
+
     if options.output:
         cparser = A.find_loader(options.output, options.otype)
         cparser.dump(data, options.output)
