@@ -5,10 +5,11 @@
 """anyconfig globals.
 """
 import logging
+import os
 
 
 AUTHOR = 'Satoru SATOH <ssat@redhat.com>'
-VERSION = "0.0.3.12"
+VERSION = "0.0.3.13"
 
 _LOGGING_FORMAT = "%(asctime)s %(name)s: [%(levelname)s] %(message)s"
 
@@ -18,6 +19,9 @@ def get_logger(name="anyconfig", log_format=_LOGGING_FORMAT,
     """
     Initialize custom logger.
     """
+    if os.environ.get("ANYCONFIG_DEBUG", False):
+        level = logging.DEBUG
+
     logging.basicConfig(level=level, format=log_format)
     logger = logging.getLogger(name)
 
