@@ -4,9 +4,14 @@
 #
 """Merge-able dict.
 """
-from anyconfig.compat import iteritems
+from __future__ import absolute_import
+
+from .compat import iteritems
+from . import utils as U
+# pylint: disable=C0103
+from .getset import get  # flake8: noqa
+# pylint: enable=C0103
 
-import anyconfig.utils as U
 import copy
 
 # TODO: Keep items' order:
